@@ -1,5 +1,5 @@
 "l2nu" <- 
 function(lambda)
 {
-	10.^7./lambda
+	10^7/lambda
 }
